<?php

/**
 * JEG Portfolio Class
 *
 * @package jeg-portfolio
 *
 * @author Jegtheme
 *
 * @since 1.0.0
 */

namespace Jeg\Portfolio\Asset;

/**
 * Class Asset
 *
 * @package Jeg\Portfolio\Asset
 */
class Asset {
    /**
     * @var Asset
     */
    private static $instance;

    /**
     * Metaboxes constructor.
     */
    public function __construct() {
        $this->setup_init();
        $this->setup_hook();
    }

    /**
     * @return Asset
     */
    public static function instance() {
        if ( null === static::$instance ) {
            static::$instance = new static();
        }

        return static::$instance;
    }

    /**
     * Setup Classes
     */
    private function setup_init() {
    }

    /**
     * Setup Hooks
     */
    private function setup_hook() {
        add_action( 'wp_enqueue_scripts', [$this, 'init_scripts'] );
        add_action( 'wp_enqueue_scripts', [$this, 'init_styles'] );
    }

    /**
     * Register Scripts
     */
    public function init_scripts() {
        global $post;

        if ( ! jeg_portfolio_is_login_page() && is_jeg_portfolio_page() ) {
            wp_enqueue_script( 'wp-mediaelement' );

            // external script
            wp_enqueue_script( 'fotorama', JEG_PORTFOLIO_URL . '/assets/js/frontend/external/fotorama.js', null, JEG_PORTFOLIO_VERSION, true );
            wp_enqueue_script( 'isotope', JEG_PORTFOLIO_URL . '/assets/js/frontend/external/jquery.isotope.min.js', null, JEG_PORTFOLIO_VERSION, true );
            wp_enqueue_script( 'magnific', JEG_PORTFOLIO_URL . '/assets/js/frontend/external/jquery.magnific-popup.min.js', null, JEG_PORTFOLIO_VERSION, true );
            wp_enqueue_script( 'swipebox', JEG_PORTFOLIO_URL . '/assets/js/frontend/external/jquery.swipebox.js', null, JEG_PORTFOLIO_VERSION, true );
            wp_enqueue_script( 'hoverintent', JEG_PORTFOLIO_URL . '/assets/js/frontend/external/jquery.hoverintent.js', null, JEG_PORTFOLIO_VERSION, true );
            wp_enqueue_script( 'easing', JEG_PORTFOLIO_URL . '/assets/js/frontend/external/jquery.easing.js', null, JEG_PORTFOLIO_VERSION, true );
            wp_enqueue_script( 'imgloaded', JEG_PORTFOLIO_URL . '/assets/js/frontend/external/jquery.imgloaded.js', null, JEG_PORTFOLIO_VERSION, true );
            wp_enqueue_script( 'iosslider', JEG_PORTFOLIO_URL . '/assets/js/frontend/external/jquery.iosslider.min.js', null, JEG_PORTFOLIO_VERSION, true );
            wp_enqueue_script( 'migrate', JEG_PORTFOLIO_URL . '/assets/js/frontend/external/jquery.migrate.js', null, JEG_PORTFOLIO_VERSION, true );
            wp_enqueue_script( 'jscrollpane', JEG_PORTFOLIO_URL . '/assets/js/frontend/external/jquery.jscrollpane.js', null, JEG_PORTFOLIO_VERSION, true);

			// internal script
            if ( ! is_admin() && ! SCRIPT_DEBUG ) {
				wp_enqueue_script( 'jeg-main', JEG_PORTFOLIO_URL . '/assets/js/frontend/internal/script.min.js', null, JEG_PORTFOLIO_VERSION, true );
            } else {
                wp_enqueue_script( 'jeg-common', JEG_PORTFOLIO_URL . '/assets/js/frontend/internal/common.js', null, JEG_PORTFOLIO_VERSION, true );
                wp_enqueue_script( 'jeg-gallery', JEG_PORTFOLIO_URL . '/assets/js/frontend/internal/jquery.gallery.js', null, JEG_PORTFOLIO_VERSION, true );
                wp_enqueue_script( 'jeg-normalblog', JEG_PORTFOLIO_URL . '/assets/js/frontend/internal/jquery.jnormalblog.js', null, JEG_PORTFOLIO_VERSION, true );
                wp_enqueue_script( 'jeg-single-portfolio', JEG_PORTFOLIO_URL . '/assets/js/frontend/internal/jquery.jportfoliosingle.js', null, JEG_PORTFOLIO_VERSION, true );
                wp_enqueue_script( 'jeg-masonryblog', JEG_PORTFOLIO_URL . '/assets/js/frontend/internal/jquery.jmasonryblog.js', null, JEG_PORTFOLIO_VERSION, true );
                wp_enqueue_script( 'jeg-main', JEG_PORTFOLIO_URL . '/assets/js/frontend/internal/main.js', null, JEG_PORTFOLIO_VERSION, true );
            }

            if ( is_page() ) {
                $template = get_post_meta( $post->ID, '_wp_page_template', true );

                if ( 'template-portfolio.php' === $template ) {
                    wp_enqueue_script( 'jeg-portfolio', JEG_PORTFOLIO_URL . '/assets/js/frontend/internal/jquery.jportfolio.js', null, JEG_PORTFOLIO_VERSION, true );
                }
            }

            if ( is_singular() ) {
                wp_enqueue_script( 'comment-reply' );
            }

            wp_localize_script( 'jeg-main', 'joption', $this->get_admin_js_option() );
        }
    }

    public function init_styles() {
        if ( ! jeg_portfolio_is_login_page() && is_jeg_portfolio_page() ) {
            wp_enqueue_style( 'wp-mediaelement' );
        }
    }

    /**
     * @return array
     */
    private function get_admin_js_option() {
        global $is_IE;

        $option               = [];
        $option['ajaxurl']    = apply_filters( 'jeg_remove_http', admin_url( 'admin-ajax.php' ) );
        $option['ismobile']   = wp_is_mobile();
        $option['isie']       = $is_IE;
        $option['shareto']    = esc_html__( 'Share Article to', 'jeg-portfolio' );
        $option['plugin_url'] = JEG_PORTFOLIO_URL;

        return $option;
    }
}
