<?php

/**
 * JEG Portfolio Class
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package jeg-portfolio
 */

namespace Jeg\Portfolio\Customizer;

/**
 * Class Customizer
 *
 * @package Jeg\Portfolio\Customizer
 */
class Customizer {
	/**
	 * @var Customizer
	 */
	private static $instance;

	/**
	 * Metaboxes constructor.
	 */
	public function __construct() {
		$this->setup_init();
		$this->setup_hook();
	}

	/**
	 * @return Customizer
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}

	/**
	 * Setup Classes
	 */
	private function setup_init() {

	}

	/**
	 * Setup Hooks
	 */
	private function setup_hook() {
		add_action( 'jeg_register_customizer_option', [ $this, 'customizer_option' ] );
		add_filter( 'jeg_register_lazy_section', [ $this, 'autoload_section' ] );
	}

	/**
	 * Register Customizer using jeg-framework
	 */
	public function customizer_option() {
		if ( class_exists( 'Jeg\Customizer\Customizer' ) ) {
			$this->customizer = \Jeg\Customizer\Customizer::get_instance();

			$this->set_panel();
			$this->set_section();
		}
	}

	/**
	 * Add new panel
	 */
	public function set_panel() {
		$this->customizer->add_panel(
			[
				'id'          => 'jeg_portfolio_panel',
				'title'       => esc_html__( 'JEG: Portfolio Option', 'jeg-portfolio' ),
				'description' => esc_html__( 'Portfolio Options', 'jeg-portfolio' ),
				'priority'    => 200,
			]
		);
	}

	/**
	 * Add new section in the panel
	 */
	public function set_section() {
		$this->customizer->add_section(
			[
				'id'       => 'jeg_portfolio_search',
				'title'    => esc_html__( 'Search Option', 'jeg-portfolio' ),
				'panel'    => 'jeg_portfolio_panel',
				'priority' => 262,
				'type'     => 'jeg-lazy-section',
			]
		);
		$this->customizer->add_section(
			[
				'id'       => 'jeg_portfolio_social',
				'title'    => esc_html__( 'Social Share', 'jeg-portfolio' ),
				'panel'    => 'jeg_portfolio_panel',
				'priority' => 263,
				'type'     => 'jeg-lazy-section',
			]
		);
		$this->customizer->add_section(
			[
				'id'       => 'jeg_portfolio_font',
				'title'    => esc_html__( 'Font Option', 'jeg-portfolio' ),
				'panel'    => 'jeg_portfolio_panel',
				'priority' => 264,
				'type'     => 'jeg-lazy-section',
			]
		);
		$this->customizer->add_section(
			[
				'id'       => 'jeg_portfolio_style',
				'title'    => esc_html__( 'Style Option', 'jeg-portfolio' ),
				'panel'    => 'jeg_portfolio_panel',
				'priority' => 265,
				'type'     => 'jeg-lazy-section',
			]
		);
	}

	/**
	 * Load Customizer Option
	 *
	 * @param $result
	 *
	 * @return mixed
	 */
	public function autoload_section( $result ) {
		$result['jeg_portfolio_social'][]  = JEG_PORTFOLIO_DIR . 'class/customizer/options/customizer-social.php';
		$result['jeg_portfolio_search'][] = JEG_PORTFOLIO_DIR . 'class/customizer/options/customizer-search.php';
		$result['jeg_portfolio_font'][]    = JEG_PORTFOLIO_DIR . 'class/customizer/options/customizer-font.php';
		$result['jeg_portfolio_style'][]    = JEG_PORTFOLIO_DIR . 'class/customizer/options/customizer-style.php';

		return $result;
	}

}
