<?php

/**
 * JEG Portfolio Class
 *
 * @package jeg-portfolio
 *
 * @author Jegtheme
 *
 * @since 1.0.0
 */

namespace Jeg\Portfolio\Dashboard;

/**
 * Class Dashboard
 *
 * @package Jeg\Portfolio\Dashboard
 */
class Dashboard {
    /**
     * @var Dashboard
     */
    private static $instance;

    /**
     * Metaboxes constructor.
     */
    public function __construct() {
        $this->setup_init();
        $this->setup_hook();
    }

    /**
     * @return Dashboard
     */
    public static function instance() {
        if ( null === static::$instance ) {
            static::$instance = new static();
        }

        return static::$instance;
    }

    /**
     * Setup Classes
     */
    private function setup_init() {
    }

    /**
     * Setup Hooks
     */
    private function setup_hook() {
        // integration jeg-element
        add_filter( 'jeg_show_default_module_customizer', '__return_false' );

        // integration epic-dashboard
        add_filter( 'epic_parent_menu', [$this, 'epic_parent_menu'] );
        add_filter( 'epic_plugin_list', [$this, 'epic_plugin_list'] );
        add_filter( 'epic_dashboard_welcome_string', [$this, 'epic_welcome_string'] );
        add_filter( 'epic_dashboard_about_string', [$this, 'epic_about_string'] );
        add_filter( 'epic_admin_menu', [$this, 'admin_menu'], 20 );

        epic_activation_hook( JEG_PORTFOLIO_FILE );
    }

    /**
     * Get plugin data
     *
     * @param  $plugins
     * @return array
     */
    public function epic_plugin_list( $plugins ) {
        $plugins[] = [
            'id'      => JEG_PORTFOLIO_ID,
            'name'    => JEG_PORTFOLIO_NAME,
            'slug'    => JEG_PORTFOLIO,
            'version' => JEG_PORTFOLIO_VERSION,
            'option'  => 'jeg_portfolio_license',
            'file'    => JEG_PORTFOLIO_FILE,
        ];

        return $plugins;
    }

    /**
     * Override parent menu
     *
     * @param  $value
     * @return mixed
     */
    public function epic_parent_menu( $value ) {
        $value['page_title'] = esc_html__( 'Jegtheme', 'jeg-portfolio' );
        $value['menu_title'] = esc_html__( 'Jegtheme', 'jeg-portfolio' );

        return $value;
    }

    /**
     * Override welcome string
     * epic-dashboard lib
     *
     * @param  $value
     * @return string
     */
    public function epic_welcome_string( $value ) {
        return wp_kses( __( 'Welcome to <strong>Jeg Portfolio</strong> plugin', 'jeg-portfolio' ), wp_kses_allowed_html() );
    }

    /**
     * Override about string
     * epic-dashboard lib
     *
     * @param  $value
     * @return string
     */
    public function epic_about_string( $value ) {
        return wp_kses( __( 'Please activate the plugin license to get official support service and automatic update. Read below for additional information.', 'jeg-portfolio' ), wp_kses_allowed_html() );
    }

    /**
     * Admin dashboard
     *
     * @param  $menu
     * @return array
     */
    public function admin_menu( $menu ) {
        array_push(
            $menu,
            [
                'title'        => esc_html__( 'Portfolio Import', 'jeg-portfolio' ),
                'menu'         => esc_html__( 'Portfolio Import', 'jeg-portfolio' ),
                'slug'         => 'jeg_portfolio_import',
                'action'       => [$this, 'dashboard_import'],
                'priority'     => 55,
                'show_on_menu' => true,
            ]
        );

        return $menu;
    }

    /**
     * Render portfolio import
     */
    public static function dashboard_import() {
        require_once JEG_PORTFOLIO_DIR . 'class/dashboard/panel/import-content.php';
    }
}
