<?php

/**
 * JEG Portfolio Class
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package jeg-portfolio-paypal
 */

namespace Jeg\Portfolio\Metaboxes\Metabox;

use Jeg\Form\Form_Meta_Box;

/**
 * Class Another_Page_Setting
 *
 * @package Jeg\Portfolio\Another_Page_Setting
 */
class Another_Page_Setting {
	/**
	 * @var Meta
	 */
	private static $instance;

	/**
	 * Metabox constructor.
	 */
	public function __construct() {
		add_action( 'plugins_loaded', [ $this, 'initialize_metabox' ] );
	}

	/**
	 * Intialize meta box using jeg-framework
	 */
	public function initialize_metabox() {
		$segments = $this->metabox_segments();
		$fields   = $this->metabox_fields();

		$option = [
			'id'        => 'jpt_another_page_setting',
			'title'     => esc_html__( 'JEG: Portfolio Another Page Setting', 'jeg-portfolio' ),
			'post_type' => 'portfolio',
			'type'      => 'normal',
			'segments'  => $segments,
			'fields'    => $fields,
		];

		if ( class_exists( 'Jeg\Form\Form_Meta_Box' ) ) {
			new Form_Meta_Box( $option );
		}
	}

	/**
	 * Create meta box segments
	 *
	 * @return array
	 */
	protected function metabox_segments() {
		$segments = [];

		$segments['another_page_setting'] = [
			'name'     => esc_html__( 'Another Page Setting', 'jeg-portfolio' ),
			'priority' => 2,
		];

		return $segments;
	}

	/**
	 * Create meta box fields
	 *
	 * @return array
	 */
	protected function metabox_fields() {
		$fields = [];

		$fields['page_link'] = [
			'segment' => 'another_page_setting',
			'type'    => 'text',
			'title'   => esc_attr__( 'Link to another page', 'jeg-portfolio' ),
			'default' => '',
		];

		return $fields;
	}

	/**
	 * @return Meta
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}


}
