<?php

/**
 * JEG Portfolio Class
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package jeg-portfolio-paypal
 */

namespace Jeg\Portfolio\Metaboxes\Metabox;

use Jeg\Form\Form_Meta_Box;

/**
 * Class Media_Builder
 *
 * @package Jeg\Portfolio\Media_Builder
 */
class Media_Builder {
	/**
	 * @var Meta
	 */
	private static $instance;

	/**
	 * Metabox constructor.
	 */
	public function __construct() {
		add_action( 'plugins_loaded', [ $this, 'initialize_metabox' ] );
	}

	/**
	 * Intialize meta box using jeg-framework
	 */
	public function initialize_metabox() {
		$segments = $this->metabox_segments();
		$fields   = $this->metabox_fields();

		$option = [
			'id'        => 'jpt_media_builder_metabox',
			'title'     => esc_html__( 'JEG: Portfolio Media Gallery Builder', 'jeg-portfolio' ),
			'post_type' => 'portfolio',
			'type'      => 'normal',
			'segments'  => $segments,
			'fields'    => $fields,
		];

		if ( class_exists( 'Jeg\Form\Form_Meta_Box' ) ) {
			new Form_Meta_Box( $option );
		}
	}

	/**
	 * Create meta box segments
	 *
	 * @return array
	 */
	protected function metabox_segments() {
		$segments = [];

		$segments['media_builder_setting'] = [
			'name'     => esc_html__( 'Portfolio Media Builder Setting', 'jeg-portfolio' ),
			'priority' => 3,
		];

		return $segments;
	}

	/**
	 * Create meta box fields
	 *
	 * @return array
	 */
	protected function metabox_fields() {
		$fields = [];

		$fields['portfolio_media_builder'] = [
			'segment'     => 'media_builder_setting',
			'type'        => 'repeater',
			'title'       => esc_attr__( 'Media Builder', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Add media builder', 'jeg-portfolio' ),
			'default'     => [],
			'choices'     => [
				'limit' => '',
			],
			'row_label'   => [
				'type'  => 'text',
				'value' => esc_attr__( 'Media Builder', 'jeg-portfolio' ),
				'field' => false,
			],
			'fields'      => [
				'media_type'   => [
					'type'    => 'select',
					'label'   => esc_attr__( 'Select Media Type', 'jeg-portfolio' ),
					'default' => 'image',
					'choices' => [
						'image'      => esc_html__( 'Image', 'jeg-portfolio' ),
						'youtube'    => esc_html__( 'Youtube', 'jeg-portfolio' ),
						'vimeo'      => esc_html__( 'Vimeo', 'jeg-portfolio' ),
						'soundcloud' => esc_html__( 'Soundcloud', 'jeg-portfolio' ),
						'html5video' => esc_html__( 'HTML Video', 'jeg-portfolio' ),
					],
					'id'      => 'media_type',
				],
				'media_image'  => [
					'type'    => 'image',
					'label'   => esc_attr__( 'Select Image', 'jeg-portfolio' ),
					'default' => '',
					'id'      => 'media_image',
				],
				'media_url'    => [
					'type'    => 'text',
					'label'   => esc_attr__( 'Insert URL', 'jeg-portfolio' ),
					'default' => '',
					'id'      => 'media_url',
				],
				'media_title'  => [
					'type'    => 'text',
					'label'   => esc_attr__( 'Insert Title', 'jeg-portfolio' ),
					'default' => '',
					'id'      => 'media_title',
				],
				'image_cover'  => [
					'type'    => 'image',
					'label'   => esc_attr__( 'Image Cover', 'jeg-portfolio' ),
					'default' => '',
					'id'      => 'image_cover',
				],
				'video_mp4'  => [
					'type'    => 'upload',
					'label'   => esc_attr__( 'Select Video (MP4)', 'jeg-portfolio' ),
					'default' => '',
					'id'      => 'video_mp4',
				],
				'video_webm'  => [
					'type'    => 'upload',
					'label'   => esc_attr__( 'Select Video (WEBM)', 'jeg-portfolio' ),
					'default' => '',
					'id'      => 'video_webm',
				],
				'video_ogg'  => [
					'type'    => 'upload',
					'label'   => esc_attr__( 'Select Video (OGG)', 'jeg-portfolio' ),
					'default' => '',
					'id'      => 'video_ogg',
				],
				'thumb_width'  => [
					'type'    => 'select',
					'label'   => esc_attr__( 'Thumb Width', 'jeg-portfolio' ),
					'default' => '1x',
					'choices' => [
						'1/4x' => esc_html__( '1/4 Width', 'jeg-portfolio' ),
						'1/2x' => esc_html__( '1/2 Width', 'jeg-portfolio' ),
						'1x'   => esc_html__( '1 Width', 'jeg-portfolio' ),
						'2x'   => esc_html__( '2 Width', 'jeg-portfolio' ),
						'3x'   => esc_html__( '3 Width', 'jeg-portfolio' ),
					],
					'id'      => 'thumb_width',
				],
				'thumb_height' => [
					'type'    => 'select',
					'label'   => esc_attr__( 'Thumb Height', 'jeg-portfolio' ),
					'default' => '1x',
					'choices' => [
						'1/4x' => esc_html__( '1/4 Height', 'jeg-portfolio' ),
						'1/2x' => esc_html__( '1/2 Height', 'jeg-portfolio' ),
						'1x'   => esc_html__( '1 Height', 'jeg-portfolio' ),
						'2x'   => esc_html__( '2 Height', 'jeg-portfolio' ),
						'3x'   => esc_html__( '3 Height', 'jeg-portfolio' ),
					],
					'id'      => 'thumb_height',
				],
			],
		];

		return $fields;
	}

	/**
	 * @return Meta
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}
}
