<?php

/**
 * JEG Portfolio Class
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package jeg-portfolio-paypal
 */

namespace Jeg\Portfolio\Metaboxes\Metabox;

use Jeg\Form\Form_Meta_Box;

/**
 * Class Meta
 *
 * @package Jeg\Portfolio\Meta
 */
class Meta {
	/**
	 * @var Meta
	 */
	private static $instance;

	/**
	 * Metabox constructor.
	 */
	public function __construct() {
		add_action( 'plugins_loaded', [ $this, 'initialize_metabox' ] );
	}

	/**
	 * Intialize meta box using jeg-framework
	 */
	public function initialize_metabox() {
		$segments = $this->metabox_segments();
		$fields   = $this->metabox_fields();

		$option = [
			'id'        => 'jpt_meta_metabox',
			'title'     => esc_html__( 'JEG: Portfolio Meta', 'jeg-portfolio' ),
			'post_type' => 'portfolio',
			'type'      => 'normal',
			'segments'  => $segments,
			'fields'    => $fields,
		];

		if ( class_exists( 'Jeg\Form\Form_Meta_Box' ) ) {
			new Form_Meta_Box( $option );
		}
	}

	/**
	 * Create meta box segments
	 *
	 * @return array
	 */
	protected function metabox_segments() {
		$segments = [];

		$segments['meta_setting'] = [
			'name'     => esc_html__( 'Portfolio Meta Setting', 'jeg-portfolio' ),
			'priority' => 1,
		];

		return $segments;
	}

	/**
	 * Create meta box fields
	 *
	 * @return array
	 */
	protected function metabox_fields() {
		$fields = [];

		$fields['portfolio_meta'] = [
			'segment'     => 'meta_setting',
			'type'        => 'repeater',
			'title'       => esc_attr__( 'Portfolio Meta', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Add portfolio meta', 'jeg-portfolio' ),
			'default'     => [],
			'choices'     => [
				'limit' => '',
			],
			'row_label'   => [
				'type'  => 'text',
				'value' => esc_attr__( 'Portfolio Meta', 'jeg-portfolio' ),
				'field' => false,
			],
			'fields'      => [
				'meta_title'       => [
					'type'    => 'text',
					'label'   => esc_attr__( 'Meta Title', 'jeg-portfolio' ),
					'default' => '',
					'id'      => 'meta_title',
				],
				'meta_content'     => [
					'type'    => 'text',
					'label'   => esc_attr__( 'Meta Content', 'jeg-portfolio' ),
					'default' => '',
					'id'      => 'meta_content',
				],
				'meta_content_url' => [
					'type'        => 'text',
					'label'       => esc_attr__( 'Meta Content Link', 'jeg-portfolio' ),
					'description' => __( 'Leave empty if you don\'t have link to this portfolio meta', 'jeg-portfolio' ),
					'default'     => '',
					'id'          => 'meta_content_url',
				],
			],
		];

		$fields['enable_project_link'] = [
			'segment'     => 'meta_setting',
			'type'        => 'checkbox',
			'title'       => esc_attr__( 'Enable Project Link', 'jeg-portfolio' ),
			'description' => esc_attr__( 'show or enabling project link.', 'jeg-portfolio' ),
			'default'     => false,
		];

		$fields['project_link'] = [
			'segment'     => 'meta_setting',
			'type'        => 'repeater',
			'title'       => esc_attr__( 'Project Link', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Add project link', 'jeg-portfolio' ),
			'default'     => [],
			'choices'     => [
				'limit' => '',
			],
			'row_label'   => [
				'type'  => 'text',
				'value' => esc_attr__( 'Project Link', 'jeg-portfolio' ),
				'field' => false,
			],
			'fields'      => [
				'title'   => [
					'type'    => 'text',
					'label'   => esc_attr__( 'Portfolio Link Title', 'jeg-portfolio' ),
					'default' => '',
					'id'      => 'title',
				],
				'content' => [
					'type'    => 'text',
					'label'   => esc_attr__( 'Portfolio Link Content', 'jeg-portfolio' ),
					'default' => '',
					'id'      => 'content',
				],
				'url'     => [
					'type'    => 'text',
					'label'   => esc_attr__( 'Portfolio Link URL', 'jeg-portfolio' ),
					'default' => '',
					'id'      => 'url',
				],
			],
			'dependency'  => [
				[
					'field'    => 'enable_project_link',
					'operator' => '==',
					'value'    => true,
				],
			],
		];

		return $fields;
	}

	/**
	 * @return Meta
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}
}
