<?php

/**
 * JEG Portfolio Class
 *
 * @package jeg-portfolio-paypal
 *
 * @author Jegtheme
 *
 * @since 1.0.0
 */

namespace Jeg\Portfolio\Metaboxes\Metabox;

use Jeg\Form\Form_Meta_Box;

/**
 * Class Portfolio_General_Option
 *
 * @package Jeg\Portfolio\Portfolio_General_Option
 */
class Portfolio_General_Option {
    /**
     * @var Meta
     */
    private static $instance;

    /**
     * Metabox constructor.
     */
    public function __construct() {
        add_action( 'plugins_loaded', [$this, 'initialize_metabox'] );
    }

    /**
     * Intialize meta box using jeg-framework
     */
    public function initialize_metabox() {
        $segments = $this->metabox_segments();
        $fields   = $this->metabox_fields();

        $option = [
            'id'        => 'jpt_general_option_metabox',
            'title'     => esc_html__( 'JEG: Portfolio General Option', 'jeg-portfolio' ),
            'post_type' => 'page',
            'type'      => 'normal',
            'context'   => 'side',
            'segments'  => $segments,
            'fields'    => $fields,
        ];

        if ( class_exists( 'Jeg\Form\Form_Meta_Box' ) ) {
            new Form_Meta_Box( $option );
        }
    }

    /**
     * Create meta box segments
     *
     * @return array
     */
    protected function metabox_segments() {
        $segments = [];

        $segments['jpt_general_option_metabox_setting'] = [
            'name'     => esc_html__( 'Portfolio General Option', 'jeg-portfolio' ),
            'priority' => 'low',
        ];

        return $segments;
    }

    /**
     * Create meta box fields
     *
     * @return array
     */
    protected function metabox_fields() {
        $fields = [];

        $fields['overide_default_background_setup'] = [
            'segment'     => 'jpt_general_option_metabox_setting',
            'type'        => 'checkbox',
            'title'       => esc_attr__( 'Override Default Background Setup', 'jeg-portfolio' ),
            'description' => esc_attr__( 'if you want this page having different background', 'jeg-portfolio' ),
            'default'     => false,
        ];

        $fields['overide_default_background_color'] = [
            'segment'    => 'jpt_general_option_metabox_setting',
            'type'       => 'color',
            'title'      => esc_attr__( 'Background Color', 'jeg-portfolio' ),
            'default'    => '#FFF',
            'dependency' => [
                [
                    'field'    => 'overide_default_background_setup',
                    'operator' => '==',
                    'value'    => true,
                ],
            ],
        ];

        $fields['overide_default_background_image'] = [
            'segment'    => 'jpt_general_option_metabox_setting',
            'type'       => 'image',
            'title'      => esc_attr__( 'Background Image', 'jeg-portfolio' ),
            'dependency' => [
                [
                    'field'    => 'overide_default_background_setup',
                    'operator' => '==',
                    'value'    => true,
                ],
            ],
        ];

        $fields['overide_default_background_vertical'] = [
            'segment' => 'jpt_general_option_metabox_setting',
            'type'    => 'select',
            'title'   => esc_attr__( 'Background Vertical Position', 'jeg-portfolio' ),
            'default' => 'center',
            'options' => [
                ''       => '',
                'top'    => esc_html__( 'Top', 'jeg-portfolio' ),
                'center' => esc_html__( 'Center', 'jeg-portfolio' ),
                'bottom' => esc_html__( 'Bottom', 'jeg-portfolio' ),
            ],
            'dependency' => [
                [
                    'field'    => 'overide_default_background_setup',
                    'operator' => '==',
                    'value'    => true,
                ],
            ],
        ];

        $fields['overide_default_background_horizontal'] = [
            'segment' => 'jpt_general_option_metabox_setting',
            'type'    => 'select',
            'title'   => esc_attr__( 'Background Horizontal Position', 'jeg-portfolio' ),
            'default' => 'center',
            'options' => [
                ''       => '',
                'left'   => esc_html__( 'Left', 'jeg-portfolio' ),
                'center' => esc_html__( 'Center', 'jeg-portfolio' ),
                'right'  => esc_html__( 'Right', 'jeg-portfolio' ),
            ],
            'dependency' => [
                [
                    'field'    => 'overide_default_background_setup',
                    'operator' => '==',
                    'value'    => true,
                ],
            ],
        ];

        $fields['overide_default_background_repeat'] = [
            'segment' => 'jpt_general_option_metabox_setting',
            'type'    => 'select',
            'title'   => esc_attr__( 'Background Repeat', 'jeg-portfolio' ),
            'default' => 'no-repeat',
            'options' => [
                'no-repeat' => esc_html__( 'No Repeat', 'jeg-portfolio' ),
                'repeat'    => esc_html__( 'Repeat Image', 'jeg-portfolio' ),
                'repeat-x'  => esc_html__( 'Repeat Horizontal', 'jeg-portfolio' ),
                'repeat-y'  => esc_html__( 'Repeat Vertical', 'jeg-portfolio' ),
            ],
            'dependency' => [
                [
                    'field'    => 'overide_default_background_setup',
                    'operator' => '==',
                    'value'    => true,
                ],
            ],
        ];

        $fields['overide_default_background_fullscreen'] = [
            'segment'    => 'jpt_general_option_metabox_setting',
            'type'       => 'checkbox',
            'title'      => esc_attr__( 'Full Screen Background', 'jeg-portfolio' ),
            'default'    => false,
            'dependency' => [
                [
                    'field'    => 'overide_default_background_setup',
                    'operator' => '==',
                    'value'    => true,
                ],
            ],
        ];

        return $fields;
    }

    /**
     * @return Meta
     */
    public static function instance() {
        if ( null === static::$instance ) {
            static::$instance = new static();
        }

        return static::$instance;
    }
}
