<?php

/**
 * JEG Portfolio Class
 *
 * @package jeg-portfolio-paypal
 *
 * @author Jegtheme
 *
 * @since 1.0.0
 */

namespace Jeg\Portfolio\Metaboxes\Metabox;

use Jeg\Form\Form_Meta_Box;

/**
 * Class Portfolio_List_Option
 *
 * @package Jeg\Portfolio\Portfolio_List_Option
 */
class Portfolio_List_Option {
    /**
     * @var Meta
     */
    private static $instance;

    /**
     * Metabox constructor.
     */
    public function __construct() {
        add_action( 'plugins_loaded', [$this, 'initialize_metabox'] );
    }

    /**
     * Intialize meta box using jeg-framework
     */
    public function initialize_metabox() {
        $segments = $this->metabox_segments();
        $fields   = $this->metabox_fields();

        $option = [
            'id'        => 'jpt_list_option_metabox',
            'title'     => esc_html__( 'JEG: Portfolio List Option', 'jeg-portfolio' ),
            'post_type' => 'page',
            'type'      => 'normal',
            'segments'  => $segments,
            'fields'    => $fields,
        ];

        if ( class_exists( 'Jeg\Form\Form_Meta_Box' ) ) {
            new Form_Meta_Box( $option );
        }
    }

    /**
     * Create meta box segments
     *
     * @return array
     */
    protected function metabox_segments() {
        $segments = [];

        $segments['jpt_list_option_metabox_setting'] = [
            'name'     => esc_html__( 'Portfolio List Option', 'jeg-portfolio' ),
            'priority' => 'high',
        ];

        return $segments;
    }

    /**
     * Create meta box fields
     *
     * @return array
     */
    protected function metabox_fields() {
        $fields = [];

        $fields['portfolio_expand_mode'] = [
            'segment'     => 'jpt_list_option_metabox_setting',
            'type'        => 'select',
            'title'       => esc_attr__( 'Portfolio expand mode', 'jeg-portfolio' ),
            'description' => esc_attr__( 'portfolio expand mode', 'jeg-portfolio' ),
            'default'     => 'normal',
            'options'     => [
                'normal'    => esc_html__( 'Normal ajax expand mode', 'jeg-portfolio' ),
                'theather'  => esc_html__( 'Theather ajax expand mode', 'jeg-portfolio' ),
                'no_expand' => esc_html__( 'No expand (No Ajax)', 'jeg-portfolio' ),
            ],
        ];

        $fields['load_animation'] = [
            'segment'     => 'jpt_list_option_metabox_setting',
            'type'        => 'select',
            'title'       => esc_attr__( 'Portfolio gallery load animation style', 'jeg-portfolio' ),
            'description' => esc_attr__( 'select your animation load style', 'jeg-portfolio' ),
            'default'     => 'randomfade',
            'options'     => [
                'normal'     => esc_html__( 'Normal', 'jeg-portfolio' ),
                'fade'       => esc_html__( 'Fade', 'jeg-portfolio' ),
                'seqfade'    => esc_html__( 'Sequence Fade', 'jeg-portfolio' ),
                'upfade'     => esc_html__( 'Up Fade', 'jeg-portfolio' ),
                'sequpfade'  => esc_html__( 'Sequence Up Fade', 'jeg-portfolio' ),
                'randomfade' => esc_html__( 'Random Fade', 'jeg-portfolio' ),
            ],
        ];

        $fields['load_limit'] = [
            'segment'     => 'jpt_list_option_metabox_setting',
            'type'        => 'slider',
            'title'       => esc_attr__( 'Portfolio load per page', 'jeg-portfolio' ),
            'description' => esc_attr__( 'set your portfolio page counter', 'jeg-portfolio' ),
            'default'     => '50',
            'options'     => [
                'min'  => '1',
                'max'  => '250',
                'step' => '1',
            ],
        ];

        $fields['item_width'] = [
            'segment'     => 'jpt_list_option_metabox_setting',
            'type'        => 'slider',
            'title'       => esc_attr__( 'Portfolio item width', 'jeg-portfolio' ),
            'description' => esc_attr__( 'set your portfolio item default width, you can also change size of item width on every portfolio item setting', 'jeg-portfolio' ),
            'default'     => '400',
            'options'     => [
                'min'  => '200',
                'max'  => '1000',
                'step' => '20',
            ],
        ];

        $fields['portfolio_type'] = [
            'segment'     => 'jpt_list_option_metabox_setting',
            'type'        => 'select',
            'title'       => esc_attr__( 'Portfolio layout type', 'jeg-portfolio' ),
            'description' => esc_attr__( 'choose between normal or pinterest layout', 'jeg-portfolio' ),
            'default'     => 'normal',
            'options'     => [
                'normal'    => esc_html__( 'Normal', 'jeg-portfolio' ),
                'masonry'   => esc_html__( 'Masonry', 'jeg-portfolio' ),
                'pinterest' => esc_html__( 'Pinterest', 'jeg-portfolio' ),
            ],
        ];

        $fields['item_height'] = [
            'segment'     => 'jpt_list_option_metabox_setting',
            'type'        => 'slider',
            'title'       => esc_attr__( 'Portfolio item height dimension', 'jeg-portfolio' ),
            'description' => esc_attr__( 'item height dimension base on item width size', 'jeg-portfolio' ),
            'default'     => '1',
            'options'     => [
                'min'  => '0.1',
                'max'  => '3',
                'step' => '0.1',
            ],
            'dependency'  => [
                [
                    'field'    => 'portfolio_type',
                    'operator' => '==',
                    'value'    => 'normal',
                ],
            ],
        ];

        $fields['use_margin'] = [
            'segment'     => 'jpt_list_option_metabox_setting',
            'type'        => 'checkbox',
            'title'       => esc_attr__( 'Use portfolio margin', 'jeg-portfolio' ),
            'description' => esc_attr__( 'enable portfolio item margin on this page', 'jeg-portfolio' ),
        ];

        $fields['margin_size'] = [
            'segment'     => 'jpt_list_option_metabox_setting',
            'type'        => 'slider',
            'title'       => esc_attr__( 'Margin size', 'jeg-portfolio' ),
            'description' => esc_attr__( 'in pixel', 'jeg-portfolio' ),
            'default'     => '5',
            'options'     => [
                'min'  => '2',
                'max'  => '20',
                'step' => '1',
            ],
            'dependency'  => [
                [
                    'field'    => 'use_margin',
                    'operator' => '==',
                    'value'    => '1',
                ],
            ],

        ];

        $fields['filter_title'] = [
            'segment' => 'jpt_list_option_metabox_setting',
            'type'    => 'text',
            'title'   => esc_attr__( 'Filter Title', 'jeg-portfolio' ),
            'default' => 'Portfolio List',
        ];

        return $fields;
    }

    /**
     * @return Meta
     */
    public static function instance() {
        if ( null === static::$instance ) {
            static::$instance = new static();
        }

        return static::$instance;
    }
}
