<?php

/**
 * JEG Portfolio Class
 *
 * @package jeg-portfolio-paypal
 *
 * @author Jegtheme
 *
 * @since 1.0.0
 */

namespace Jeg\Portfolio\Metaboxes\Metabox;

use Jeg\Form\Form_Meta_Box;

/**
 * Class Portfolio_setting
 *
 * @package Jeg\Portfolio\Portfolio_setting
 */
class Portfolio_Setting {
    /**
     * @var Meta
     */
    private static $instance;

    /**
     * Metabox constructor.
     */
    public function __construct() {
        add_action( 'plugins_loaded', [$this, 'initialize_metabox'] );
    }

    /**
     * Intialize meta box using jeg-framework
     */
    public function initialize_metabox() {
        $segments = $this->metabox_segments();
        $fields   = $this->metabox_fields();

        $option = [
            'id'        => 'jpt_setting_metabox',
            'title'     => esc_html__( 'JEG: Portfolio Setting', 'jeg-portfolio' ),
            'post_type' => 'portfolio',
            'type'      => 'normal',
            'context'   => 'side',
            'segments'  => $segments,
            'fields'    => $fields,
        ];

        if ( class_exists( 'Jeg\Form\Form_Meta_Box' ) ) {
            new Form_Meta_Box( $option );
        }
    }

    /**
     * Create meta box segments
     *
     * @return array
     */
    protected function metabox_segments() {
        $segments = [];

        $segments['jpt_setting_metabox'] = [
            'name'     => esc_html__( 'Portfolio Setting', 'jeg-portfolio' ),
            'priority' => 1,
        ];

        return $segments;
    }

    /**
     * Create meta box fields
     *
     * @return array
     */
    protected function metabox_fields() {
        $fields = [];

        $fields['portfolio_layout'] = [
            'segment' => 'jpt_setting_metabox',
            'type'    => 'select',
            'title'   => esc_attr__( 'Choose your portfolio layout (for single portfolio)', 'jeg-portfolio' ),
            'options' => [
                'ajax_portfolio'         => esc_html__( 'Ajax portfolio', 'jeg-portfolio' ),
                'side_content_portfolio' => esc_html__( 'Side content portfolio', 'jeg-portfolio' ),
                'to_another_page_link'   => esc_html__( 'To another page (link)', 'jeg-portfolio' ),
            ],
        ];

        $fields['portfolio_parent'] = [
            'segment' => 'jpt_setting_metabox',
            'type'    => 'select',
            'title'   => esc_attr__( 'Choose your portfolio parent', 'jeg-portfolio' ),
            'default' => 'portfolio_normal',
            'options' => jeg_portfolio_get_portfolio_page(),
        ];

        $fields['image_cover'] = [
            'segment' => 'jpt_setting_metabox',
            'type'    => 'image',
            'title'   => esc_attr__( 'Image Cover', 'jeg-portfolio' ),
            'default' => '',
        ];

        $fields['thumb_width'] = [
            'segment'     => 'jpt_setting_metabox',
            'type'        => 'select',
            'title'       => esc_attr__( 'Thumb Width', 'jeg-portfolio' ),
            'description' => esc_attr__( 'Only if you are using normal mode on portfolio list' ),
            'default'     => '1x_width',
            'options'     => [
                '0.25' => esc_html__( '1/4x width', 'jeg-portfolio' ),
                '0.5'  => esc_html__( '1/2x width', 'jeg-portfolio' ),
                '1'    => esc_html__( '1x width', 'jeg-portfolio' ),
                '2'    => esc_html__( '2x width', 'jeg-portfolio' ),
                '3'    => esc_html__( '3x width', 'jeg-portfolio' ),
            ],
        ];

        $fields['thumb_height'] = [
            'segment'     => 'jpt_setting_metabox',
            'type'        => 'select',
            'title'       => esc_attr__( 'Thumb Height', 'jeg-portfolio' ),
            'description' => esc_attr__( 'Only if you are using normal mode on portfolio list' ),
            'default'     => '1x_height',
            'options'     => [
                '0.25' => esc_html__( '1/4x height', 'jeg-portfolio' ),
                '0.5'  => esc_html__( '1/2x height', 'jeg-portfolio' ),
                '1'    => esc_html__( '1x height', 'jeg-portfolio' ),
                '2'    => esc_html__( '2x height', 'jeg-portfolio' ),
                '3'    => esc_html__( '3x height', 'jeg-portfolio' ),
            ],
        ];

        return $fields;
    }

    /**
     * @return Meta
     */
    public static function instance() {
        if ( null === static::$instance ) {
            static::$instance = new static();
        }

        return static::$instance;
    }
}
