<?php

/**
 * JEG Portfolio Class
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package jeg-portfolio-paypal
 */

namespace Jeg\Portfolio\Metaboxes\Metabox;

use Jeg\Form\Form_Meta_Box;

/**
 * Class Side_Content_Setting
 *
 * @package Jeg\Portfolio\Side_Content_Setting
 */
class Side_Content_Setting {
	/**
	 * @var Meta
	 */
	private static $instance;

	/**
	 * Metabox constructor.
	 */
	public function __construct() {
		add_action( 'plugins_loaded', [ $this, 'initialize_metabox' ] );
	}

	/**
	 * Intialize meta box using jeg-framework
	 */
	public function initialize_metabox() {
		$segments = $this->metabox_segments();
		$fields   = $this->metabox_fields();

		$option = [
			'id'        => 'jpt_side_content_setting_metabox',
			'title'     => esc_html__( 'JEG: Portfolio Side Content Setting', 'jeg-portfolio' ),
			'post_type' => 'portfolio',
			'type'      => 'normal',
			'segments'  => $segments,
			'fields'    => $fields,
		];

		if ( class_exists( 'Jeg\Form\Form_Meta_Box' ) ) {
			new Form_Meta_Box( $option );
		}
	}

	/**
	 * Create meta box segments
	 *
	 * @return array
	 */
	protected function metabox_segments() {
		$segments = [];

		$segments['side_content_setting'] = [
			'name'     => esc_html__( 'Side Content Setting', 'jeg-portfolio' ),
			'priority' => 2,
		];

		return $segments;
	}

	/**
	 * Create meta box fields
	 *
	 * @return array
	 */
	protected function metabox_fields() {
		$fields = [];

		$fields['load_limit'] = [
			'segment'     => 'side_content_setting',
			'type'        => 'slider',
			'title'       => esc_attr__( 'Loaded Image Count', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Set your loaded image count, this option will enable you to load image step by step', 'jeg-portfolio' ),
			'options'     => [
				'min'  => '5',
				'max'  => '250',
				'step' => '1',
			],
			'default'     => '7',
		];

		$fields['switch_position'] = [
			'segment'     => 'side_content_setting',
			'type'        => 'checkbox',
			'title'       => esc_attr__( 'Switch Content Position to Left', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Enable this option to switch content position to left and image position to right', 'jeg-portfolio' ),
			'default'     => false,
		];

		$fields['gallery_type'] = [
			'segment'     => 'side_content_setting',
			'type'        => 'select',
			'title'       => esc_attr__( 'Gallery layout type', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Choose between normal or masonry layout', 'jeg-portfolio' ),
			'default'     => 'normal',
			'options'     => [
				'normal'    => esc_html__( 'Normal Layout', 'jeg-portfolio' ),
				'masonry'   => esc_html__( 'Masonry Layout', 'jeg-portfolio' ),
				'justified' => esc_html__( 'Justified Layout (Flickr or Google image)', 'jeg-portfolio' ),
			],
		];

		$fields['item_width'] = [
			'segment'     => 'side_content_setting',
			'type'        => 'slider',
			'title'       => esc_attr__( 'Gallery item width', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Set your gallery item defaul width, you can also change size of item width on every content of media gallery', 'jeg-portfolio' ),
			'options'     => [
				'min'  => '200',
				'max'  => '1000',
				'step' => '5',
			],
			'default'     => '400',
			'dependency'  => [
				[
					'field'    => 'gallery_type',
					'operator' => 'in',
					'value'    => [ 'normal', 'masonry' ],
				],
			],
		];

		$fields['item_height'] = [
			'segment'     => 'side_content_setting',
			'type'        => 'slider',
			'title'       => esc_attr__( 'Gallery item height dimension', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Item height dimension base on item width size', 'jeg-portfolio' ),
			'options'     => [
				'min'  => '0.3',
				'max'  => '1',
				'step' => '0.1',
			],
			'default'     => '1',
			'dependency'  => [
				[
					'field'    => 'gallery_type',
					'operator' => '==',
					'value'    => 'normal',
				],
			],
		];

		$fields['justified_item_height'] = [
			'segment'     => 'side_content_setting',
			'type'        => 'slider',
			'title'       => esc_attr__( 'Justified Image Height', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Height of image on justfied gallery', 'jeg-portfolio' ),
			'options'     => [
				'min'  => '150',
				'max'  => '500',
				'step' => '10',
			],
			'default'     => '250',
			'dependency'  => [
				[
					'field'    => 'gallery_type',
					'operator' => '==',
					'value'    => 'justified',
				],
			],
		];

		$fields['expand_mode'] = [
			'segment'     => 'side_content_setting',
			'type'        => 'select',
			'title'       => esc_attr__( 'Gallery Expand Script', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Script that will used when user click the image thumbnail', 'jeg-portfolio' ),
			'default'     => 'magnific',
			'options'     => [
				'magnific' => esc_html__( 'Use magnific (Play Youtube, Vimeo, HTML 5 video, and Soundcloud media)', 'jeg-portfolio' ),
				'swipebox' => esc_html__( 'Use Swipebox (Play Youtube, Vimeo, and Soundcloud media)', 'jeg-portfolio' ),
			],
		];

		$fields['load_animation'] = [
			'segment'     => 'side_content_setting',
			'type'        => 'select',
			'title'       => esc_attr__( 'Gallery load animation style', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Select your animation load sytle', 'jeg-portfolio' ),
			'default'     => 'randomfade',
			'options'     => [
				'normal'     => esc_html__( 'Normal', 'jeg-portfolio' ),
				'fade'       => esc_html__( 'Fade', 'jeg-portfolio' ),
				'seqfade'    => esc_html__( 'Sequence Fade', 'jeg-portfolio' ),
				'upfade'     => esc_html__( 'Up Fade', 'jeg-portfolio' ),
				'sequpfade'  => esc_html__( 'Sequence Up Fade', 'jeg-portfolio' ),
				'randomfade' => esc_html__( 'Random Fade', 'jeg-portfolio' ),
			],
		];

		$fields['expand_mode'] = [
			'segment'     => 'side_content_setting',
			'type'        => 'select',
			'title'       => esc_attr__( 'Gallery Expand Script', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Script that will used when user click the image thumbnail', 'jeg-portfolio' ),
			'default'     => 'magnific',
			'options'     => [
				'magnific' => esc_html__( 'Use magnific (Play Youtube, Vimeo, HTML 5 video, and Soundcloud media)', 'jeg-portfolio' ),
				'swipebox' => esc_html__( 'Use Swipebox (Play Youtube, Vimeo, and Soundcloud media)', 'jeg-portfolio' ),
			],
		];

		$fields['use_margin'] = [
			'segment'     => 'side_content_setting',
			'type'        => 'checkbox',
			'title'       => esc_attr__( 'Use portfolio margin', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Enable item margin on this page', 'jeg-portfolio' ),
			'default'     => false,
		];

		$fields['margin_size'] = [
			'segment'     => 'side_content_setting',
			'type'        => 'slider',
			'title'       => esc_attr__( 'Margin size', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Margin size in pixel', 'jeg-portfolio' ),
			'options'     => [
				'min'  => '2',
				'max'  => '20',
				'step' => '1',
			],
			'default'     => '5',
			'dependency'  => [
				[
					'field'    => 'use_margin',
					'operator' => '==',
					'value'    => true,
				],
			],
		];

		return $fields;
	}

	/**
	 * @return Meta
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}


}
