<?php

/**
 * JEG Portfolio Class
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package jeg-portfolio-paypal
 */

namespace Jeg\Portfolio\Metaboxes\Metabox;

use Jeg\Form\Form_Meta_Box;

/**
 * Class Single_Ajax_Setting
 *
 * @package Jeg\Portfolio\Single_Ajax_Setting
 */
class Single_Ajax_Setting {
	/**
	 * @var Meta
	 */
	private static $instance;

	/**
	 * Metabox constructor.
	 */
	public function __construct() {
		add_action( 'plugins_loaded', [ $this, 'initialize_metabox' ] );
	}

	/**
	 * Intialize meta box using jeg-framework
	 */
	public function initialize_metabox() {
		$segments = $this->metabox_segments();
		$fields   = $this->metabox_fields();

		$option = [
			'id'        => 'jpt_single_ajax_setting_metabox',
			'title'     => esc_html__( 'JEG: Portfolio Single Ajax Setting', 'jeg-portfolio' ),
			'post_type' => 'portfolio',
			'type'      => 'normal',
			'segments'  => $segments,
			'fields'    => $fields,
		];

		if ( class_exists( 'Jeg\Form\Form_Meta_Box' ) ) {
			new Form_Meta_Box( $option );
		}
	}

	/**
	 * Create meta box segments
	 *
	 * @return array
	 */
	protected function metabox_segments() {
		$segments = [];

		$segments['single_ajax_setting'] = [
			'name'     => esc_html__( 'Single Ajax Setting', 'jeg-portfolio' ),
			'priority' => 2,
		];

		return $segments;
	}

	/**
	 * Create meta box fields
	 *
	 * @return array
	 */
	protected function metabox_fields() {
		$fields = [];

		$fields['image_scale_method'] = [
			'segment'     => 'single_ajax_setting',
			'type'        => 'select',
			'title'       => esc_attr__( 'Image Scale Method', 'jeg-portfolio' ),
			'description' => esc_attr__( 'Image scale method when ajax expand mode used', 'jeg-portfolio' ),
			'options'     => [
				'zoom' => esc_html__( 'Image to be zoom and cropped', 'jeg-portfolio' ),
				'fit'  => esc_html__( 'Image always fits the screen', 'jeg-portfolio' ),
			],
		];

		$fields['hide_single_image_title'] = [
			'segment'     => 'single_ajax_setting',
			'type'        => 'checkbox',
			'title'       => esc_attr__( 'Hide Single Image Title', 'jeg-portfolio' ),
			'description' => esc_attr__( 'enable this option if you didnt want to show image title', 'jeg-portfolio' ),
			'default'     => false,
		];

		return $fields;
	}

	/**
	 * @return Meta
	 */
	public static function instance() {
		if ( null === static::$instance ) {
			static::$instance = new static();
		}

		return static::$instance;
	}


}
