<?php
$queryarray = [
	'post_type'      => 'portfolio',
	'post_status'    => [ 'publish' ],
	'meta_query'     => [
		[
			'key'     => 'portfolio_parent',
			'value'   => [ JEG_PAGE_ID ],
			'compare' => 'IN',
		],
	],
	'orderby'        => 'date',
	'order'          => 'DESC',
	'posts_per_page' => jeg_metabox( 'jpt_list_option_metabox.load_limit', '50', JEG_PAGE_ID ),
	'paged'          => JEG_PORTFOLIO_PAGE,
];

if ( JEG_CATEGORY !== '' ) {
	$queryarray['tax_query'] =
		[
			[
				'taxonomy' => 'portfolio_category',
				'terms'    => JEG_CATEGORY,
				'field'    => 'id',
				'operator' => 'IN',
			],
		];
}

$usemargin            = jeg_metabox( 'jpt_list_option_metabox.use_margin', false, JEG_PAGE_ID );
$marginsize           = '';
$marginportfolioclass = '';
if ( $usemargin ) {
	$marginsize           = jeg_metabox( 'jpt_list_option_metabox.margin_size', '5', JEG_PAGE_ID );
	$marginportfolioclass = 'marginportfolio';
}

$query  = new WP_Query( $queryarray );
$result = $query->posts;
?>

<div class="portfoliocontentwrapper">
	<div class="isotopewrapper">

		<?php
		$itemwidthbase   = floatval( jeg_metabox( 'jpt_list_option_metabox.item_width', '400', JEG_PAGE_ID ) );
		$portfoliolayout = jeg_metabox( 'jpt_list_option_metabox.portfolio_type', 'normal', JEG_PAGE_ID );
		$itemheightdim   = null;
		$itemheightbase  = '';

		if ( $portfoliolayout == 'normal' ) {
			$itemheightdim  = floatval( jeg_metabox( 'jpt_list_option_metabox.item_height', null, '1' ) );
			$itemheightbase = $itemheightdim * $itemwidthbase;
		}

		foreach ( $result as $key => $value ) {
			$coverwidth  = floatval( jeg_metabox( 'jpt_setting_metabox.thumb_width', '1', $value->ID ) );
			$coverheight = floatval( jeg_metabox( 'jpt_setting_metabox.thumb_height', '1', $value->ID ) );

			// calculate width & height cover
			$itw = $itemwidthbase * $coverwidth * 1.5;
			$ith = null;
			if ( $portfoliolayout == 'normal' ) {
				$ith = $itemheightbase * $coverheight * 1.5;
			}

			$coverimage = jeg_portfolio_get_image_attachment_full( jeg_metabox( 'jpt_setting_metabox.image_cover', true, $value->ID ) );
			$thumbnail  = apply_filters( 'jeg_image_resizer', $coverimage, $itw, $ith );

			if ( empty( $thumbnail ) ) {
				$thumbnail = JEG_PORTFOLIO_URL . '/assets/img/placeholder.png';
			}

			$portfoliotype = jeg_metabox( 'jpt_setting_metabox.portfolio_layout', true, $value->ID );

			if ( $portfoliotype === 'to_another_page_link' ) {
				$portfoliolink = jeg_metabox( 'jpt_another_page_setting.page_link', null, $value->ID );
			} else {
				$portfoliolink = get_permalink( $value->ID );
			}

			if ( JEG_CATEGORY !== '' ) {
				$portfoliolink .= '?filter=' . JEG_CATEGORY;
			}

			/** term list / category */
			$termlist   = get_the_terms( $value->ID, 'portfolio_category' );
			$termstring = [];

			if ( $termlist ) {
				foreach ( $termlist as $term ) {
					if ( isset( $term->name ) ) {
						$termstring[] = $term->name;
					}
				}
			}

			$categorystring = '';
			if ( ! empty( $termstring ) ) {
				$categorystring = '<span></span><p>' . implode( ', ', $termstring ) . '</p>';
			}

			/** overlay */
			$overrideoverlay   = jeg_metabox( 'jpt_media_builder_metabox.override_overlay', false, $value->ID );
			$overlaycss        = '';
			$overlaytextswitch = '';
			if ( $overrideoverlay ) {
				$overlaydata = jeg_metabox( 'jpt_media_builder_metabox.portfolio_overlay', false, $value->ID );
				$overlaycss  = isset( $overlaydata[0] ) && isset( $overlaydata[0]['color'] ) ? "background-color: {$overlaydata[0]['color']}" : '';
				if ( isset( $overlaydata[0] ) && isset( $overlaydata[0]['switch_text'] ) ) {
					$overlaytextswitch = 'textswitch';
				}
			}

			echo "<div class='portfolioitem " . $portfoliolayout . "' style='padding:" . esc_attr( $marginsize ) . "px;' data-width='" . esc_attr( $coverwidth ) . "' data-height='" . esc_attr( $coverheight ) . "'>
                    <a href='" . esc_attr( $portfoliolink ) . "' data-type='" . esc_attr( $portfoliotype ) . "' data-id='" . esc_attr( $value->ID ) . "' style='margin: 0;'>
                        <img alt='" . esc_attr( $value->post_title ) . "' src='" . esc_attr( $thumbnail ) . "'>
                        <div class='mask " . esc_attr( $overlaytextswitch ) . "' style='" . esc_attr( $overlaycss ) . "'>
                            <div class='info'>
                                " . $categorystring . '
                                <h2>' . esc_attr( $value->post_title ) . "</h2>
                            </div>
                        </div>
                    </a>
                </div>\n";
		}
		?>

	</div>
	<div class="portfoliopagingholder">
		<div class="portfoliopagingwrapper hideme">
			<div class="pagedot">
				<ul>
					<?php
					$maxnum = $query->max_num_pages;
					for ( $i = 1; $i <= $maxnum; $i++ ) {
						$activeclass = '';
						if ( $i === 1 ) {
							$activeclass = 'active';
						}
						echo "<li data-page='" . esc_attr( $i ) . "' class='" . esc_attr( $activeclass ) . "'><span>$i</span></li>";
					}
					?>
				</ul>
			</div>
			<div class="pagetext">
				<span class="pagenow"><?php esc_html_e( 'Page', 'jeg-portfolio' ); ?> <strong class="curpage">1</strong></span>
				<span class="pagetotal"><?php esc_html_e( 'From', 'jeg-portfolio' ); ?> <strong class="totalpage"><?php echo esc_html( $query->max_num_pages ); ?></strong></span>
			</div>
		</div>
	</div>
</div>
