<?php

/**
 * Template Name: Portfolio List
 */
get_header();

if ( ! post_password_required() ) {
	$category = jeg_portfolio_get_all_category( JEG_PAGE_ID );

	$query = new WP_Query(
		[
			'post_type'      => 'portfolio',
			'meta_query'     => [
				[
					'key'     => 'portfolio_parent',
					'value'   => [ JEG_PAGE_ID ],
					'compare' => 'IN',
				],
			],
			'orderby'        => 'date',
			'order'          => 'DESC',
			'posts_per_page' => jeg_metabox( 'jpt_list_option_metabox.load_limit', '50', JEG_PAGE_ID ),
			'paged'          => 1,
		]
	);

	$result = $query->posts;
	?>
	<div class="portfolio-content header-search">
		<div class="headermenu">
			<?php if ( sizeof( $category ) > 0 ) : ?>
				<div class="portfoliofilter topleftmenu">
					<div class="portfoliofilterbutton"
						 data-text="<?php echo esc_attr( jeg_metabox( 'jpt_list_option_metabox.filter_title', 'Portfolio List', JEG_PAGE_ID ) ); ?>">
						<span><?php echo esc_html( jeg_metabox( 'jpt_list_option_metabox.filter_title', 'Portfolio List', JEG_PAGE_ID ) ); ?></span>
					</div>
					<div class="portfoliofilterlist">
						<ul>
							<li data-filter=""><?php esc_html_e( 'All Category', 'jeg-portfolio' ); ?></li>
							<?php
							foreach ( $category as $key => $cat ) :
								echo "<li data-filter='" . esc_attr( $key ) . "'> " . esc_html( $cat ) . '</li>';
							endforeach;
							?>
						</ul>
					</div>
				</div>
			<?php endif; ?>
			<?php
			 include JEG_PORTFOLIO_TEMPLATE_DIR . '/fragment/header-search-bar.php';
			?>
		</div>
	</div>
	<!-- headermenu -->
	<?php

	$pinterestclass = '';
	$usepinterest   = jeg_metabox( 'jpt_list_option_metabox.portfolio_type', 'normal', JEG_PAGE_ID );

	$marginsize           = '';
	$marginportfolioclass = '';

	if ( $usepinterest == 'pinterest' ) {
		$pinterestclass = 'pinterestportfolio';
	}

	$usemargin = jeg_metabox( 'jpt_list_option_metabox.use_margin', false, JEG_PAGE_ID );
	if ( $usemargin ) {
		$marginsize           = jeg_metabox( 'jpt_list_option_metabox.margin_size', '5', JEG_PAGE_ID );
		$marginportfolioclass = 'marginportfolio';
	}

	?>
	<div class="portfolio-content portfolio-wrapper">
		<div class="portfoliowrapper <?php echo esc_attr( $pinterestclass ); ?>">
			<?php if ( sizeof( $category ) > 0 ) : ?>
				<div class="filterfloat">
					<div class="filterfloatbutton">
						<span><?php echo esc_html( jeg_metabox( 'jpt_list_option_metabox.filter_title', 'Portfolio List', JEG_PAGE_ID ) ); ?></span>
					</div>
					<div class="filterfloatlist">
						<ul>
							<li data-filter=""><?php esc_html_e( 'All Category', 'jeg-portfolio' ); ?></li>
							<?php
							foreach ( $category as $key => $cat ) :
								echo "<li data-filter='" . esc_attr( $key ) . "'>" . esc_attr( $cat ) . '</li>';
							endforeach;
							?>
						</ul>
					</div>
				</div>
			<?php endif; ?>

			<div class="portfoliocontentwrapper <?php echo esc_attr( $marginportfolioclass ); ?>"
				 style="<?php echo 'padding: ' . esc_attr( $marginsize ) . 'px'; ?>">
				<div class="isotopewrapper">
					<?php
					$itemwidthbase   = jeg_metabox( 'jpt_list_option_metabox.item_width', null, JEG_PAGE_ID );
					$portfoliolayout = jeg_metabox( 'jpt_list_option_metabox.portfolio_type', null, JEG_PAGE_ID );
					$itemheightdim   = null;
					$itemheightbase  = '';

					if ( $portfoliolayout === 'normal' ) {
						$itemheightdim  = floatval( jeg_metabox( 'jpt_list_option_metabox.item_height', null, JEG_PAGE_ID ) );
						$itemheightbase = $itemheightdim * $itemwidthbase;
					}

					foreach ( $result as $key => $value ) {
						$coverwidth  = floatval( jeg_metabox( 'jpt_setting_metabox.thumb_width', '1', $value->ID ) );
						$coverheight = floatval( jeg_metabox( 'jpt_setting_metabox.thumb_height', '1', $value->ID ) );

						// calculate width & height cover
						$itw = $itemwidthbase * $coverwidth * 1.5;
						$ith = null;
						if ( $portfoliolayout == 'normal' ) {
							$ith = $itemheightbase * $coverheight * 1.5;
						}

						$coverimage = jeg_portfolio_get_image_attachment_full( jeg_metabox( 'jpt_setting_metabox.image_cover', true, $value->ID ) );
						$thumbnail  = apply_filters( 'jeg_image_resizer', $coverimage, $itw, $ith );

						if ( empty( $thumbnail ) ) {
							$thumbnail = JEG_PORTFOLIO_URL . '/assets/img/placeholder.png';
						}

						$portfoliotype = jeg_metabox( 'jpt_setting_metabox.portfolio_layout', true, $value->ID );

						if ( $portfoliotype === 'to_another_page_link' ) {
							$portfoliolink = jeg_metabox( 'jpt_another_page_setting.page_link', null, $value->ID );
						} else {
							$portfoliolink = get_permalink( $value->ID );
						}


						/** term list / category */
						$termlist   = get_the_terms( $value->ID, 'portfolio_category' );
						$termstring = [];

						if ( $termlist ) {
							foreach ( $termlist as $term ) {
								if ( isset( $term->name ) ) {
									$termstring[] = $term->name;
								}
							}
						}

						$categorystring = '';
						if ( ! empty( $termstring ) ) {
							$categorystring = '<span></span><p>' . implode( ', ', $termstring ) . '</p>';
						}

						/** overlay */
						$overrideoverlay   = jeg_metabox( 'jpt_media_builder_metabox.override_overlay', false, $value->ID );
						$overlaycss        = '';
						$overlaytextswitch = '';
						if ( $overrideoverlay ) {
							$overlaydata = jeg_metabox( 'jpt_media_builder_metabox.portfolio_overlay', false, $value->ID );
							$overlaycss  = isset( $overlaydata[0] ) && isset( $overlaydata[0]['color'] ) ? "background-color: {$overlaydata[0]['color']}" : '';
							if ( isset( $overlaydata[0] ) && isset( $overlaydata[0]['switch_text'] ) ) {
								$overlaytextswitch = 'textswitch';
							}
						}

						echo "<div class='portfolioitem " . $portfoliolayout . "' style='padding:" . esc_attr( $marginsize ) . "px;' data-width='" . esc_attr( $coverwidth ) . "' data-height='" . esc_attr( $coverheight ) . "'>
                            <a href='" . esc_attr( $portfoliolink ) . "' data-type='" . esc_attr( $portfoliotype ) . "' data-id='" . esc_attr( $value->ID ) . "' style='margin: 0;'>
                                <img alt='" . esc_attr( $value->post_title ) . "' src='" . esc_attr( $thumbnail ) . "'>
                                <div class='mask " . esc_attr( $overlaytextswitch ) . "' style='" . esc_attr( $overlaycss ) . "'>
                                    <div class='info'>
                                        " . $categorystring . '
                                        <h2>' . esc_attr( $value->post_title ) . "</h2>
                                    </div>
                                </div>
                            </a>
                        </div>\n";
					}
					?>
				</div>
			</div>
			<div class="portfolioinputfilter">
				<form>
					<input type="hidden" name="portfolioid" value="<?php echo esc_attr( get_the_ID() ); ?>"/>
					<input type="hidden" name="category"/>
					<input type="hidden" name="page"/>
					<input type="hidden" name="action" value="get_portfolio_filter"/>
				</form>
			</div>
		</div>
		<div class="portfolioloader bigloader"></div>
	</div>

	<div class="portfolio-content blog-pagination">
		<div class="portfoliowrapper blog-paging">
			<div class="portfoliocontentwrapper">
				<div class="portfoliopagingholder">
					<div class="portfoliopagingwrapper hideme">
						<div class="pagedot">
							<ul>
								<?php
								$maxnum = $query->max_num_pages;
								for ( $i = 1; $i <= $maxnum; $i ++ ) {
									$activeclass = '';
									if ( $i === 1 ) {
										$activeclass = 'active';
									}
									echo "<li data-page='" . esc_attr( $i ) . "' class='" . esc_attr( $activeclass ) . "'><span>$i</span></li>";
								}
								?>
							</ul>
						</div>
						<div class="pagetext">
							<span class="pagenow"><?php esc_html_e( 'Page', 'jeg-portfolio' ); ?> <strong
										class="curpage">1</strong></span>
							<span class="pagetotal"><?php esc_html_e( 'From', 'jeg-portfolio' ); ?> <strong
										class="totalpage"><?php echo esc_html( $query->max_num_pages ); ?></strong></span>
						</div>
					</div>
				</div>
			</div>
		</div>
	</div>

	<?php
	if ( jeg_metabox( 'jpt_list_option_metabox.portfolio_expand_mode', 'normal', JEG_PAGE_ID ) === 'theather' ) {
		include JEG_PORTFOLIO_TEMPLATE_DIR . '/fragment/portfolio-fragment-theather.php';
	}
	?>

	<?php
	if ( jeg_metabox( 'jpt_general_option_metabox.overide_default_background_setup', false, JEG_PAGE_ID ) ) {
		$background_image = jeg_metabox( 'jpt_general_option_metabox.overide_default_background_image', false, JEG_PAGE_ID );
		?>
		<style scoped>
			.portfolio-content.portfolio-wrapper {
				<?php
				if ( jeg_metabox( 'jpt_general_option_metabox.overide_default_background_color', '#FFF', JEG_PAGE_ID ) ) {
					echo 'background-color: ' . jeg_metabox( 'jpt_general_option_metabox.overide_default_background_color', '#FFF', JEG_PAGE_ID ) . ';';
				}
				if ( $background_image) {
					?>
					background-image: url("<?php echo urldecode( wp_get_attachment_url( $background_image ) ); ?>");
					background-position: <?php echo jeg_metabox( 'jpt_general_option_metabox.overide_default_background_horizontal', '', JEG_PAGE_ID ) . ' ' . jeg_metabox( 'jpt_general_option_metabox.overide_default_background_vertical', '', JEG_PAGE_ID ) . ';'; ?>
					background-repeat: <?php echo jeg_metabox( 'jpt_general_option_metabox.overide_default_background_repeat', 'no-repeat', JEG_PAGE_ID ) . ';'; ?>
					<?php
				}
				if ( jeg_metabox( 'jpt_general_option_metabox.overide_default_background_fullscreen', false, JEG_PAGE_ID ) ) {
					echo 'background-size: cover';
				}
				?>
			}
		</style>	
		<?php
	}
	?>

	<script>
		(function ($) {
			$(document).on('ready', function (e, data) {
				$(".portfoliowrapper:not(.blog-paging)").jportfolio({
					ajaxurl: '<?php echo esc_url( admin_url( 'admin-ajax.php' ) ); ?>',
					loadAnimation: '<?php echo esc_js( jeg_metabox( 'jpt_list_option_metabox.load_animation', 'randomfade', JEG_PAGE_ID ) ); ?>',
					portfoliosize: <?php echo esc_js( jeg_metabox( 'jpt_list_option_metabox.item_width', '400', JEG_PAGE_ID ) ); ?>,
					expandtype: '<?php echo esc_js( jeg_metabox( 'jpt_list_option_metabox.portfolio_expand_mode', 'normal', JEG_PAGE_ID ) ); ?>',
					tiletype: '<?php echo esc_js( jeg_metabox( 'jpt_list_option_metabox.portfolio_type', 'normal', JEG_PAGE_ID ) ); ?>',
					dimension: '<?php echo esc_js( floatval( jeg_metabox( 'jpt_list_option_metabox.item_height', '1', JEG_PAGE_ID ) ) ); ?>',
					margin: '<?php echo esc_js( $marginsize ); ?>'
				});
			});
		})(jQuery);
	</script>

	<?php
} else {
	include JEG_PORTFOLIO_TEMPLATE_DIR . '/fragment/password-form.php';
}
get_footer( 'portfolio' );
