<?php
/**
 * Jeg Portfolio Helper
 *
 * @author Jegtheme
 * @since 1.0.0
 * @package jeg-portfolio
 */

/**
 * Get option for Jeg Portfolio
 *
 * @param string $setting Setting name.
 * @param mixed $default Default option.
 *
 * @return mixed
 */

if ( ! function_exists( 'jeg_portfolio_get_option' ) ) {
	function jeg_portfolio_get_option( $setting, $default = null ) {
		$options = get_option( 'jeg_portfolio_option', [] );
		$value   = $default;

		if ( isset( $options[ $setting ] ) ) {
			$value = $options[ $setting ];
		}

		return $value;
	}
}

if ( ! function_exists( 'jeg_portfolio_get_sidebar_widget' ) ) {
	function jeg_portfolio_get_sidebar_widget() {
		$sidebars_widgets = $GLOBALS['wp_registered_sidebars'];
		$widgets          = [];
	
		foreach ( $sidebars_widgets as $widget ) {
			$widgets[ $widget['id'] ] = $widget['name'];
		}
	
		return $widgets;
	}
}

if ( ! function_exists('jeg_portfolio_get_sidebar' ) ) {
	function jeg_portfolio_get_sidebar( $sidebar_id = null ) {
		$result           = [];
		$sidebars_widgets = get_option( 'sidebars_widgets' );
	
		if ( is_array( $sidebars_widgets ) ) {
	
			foreach ( $sidebars_widgets as $key => $value ) {
				$result[ $key ] = $key;
			}
		}
	
		unset( $result['wp_inactive_widgets'] );
		unset( $result['array_version'] );
	
		return $result;
	}
}

if ( ! function_exists( 'jeg_portfolio_get_portfolio_page' ) ) {
	function jeg_portfolio_get_portfolio_page() {
		$result = [];
	
		$pages = get_pages(
			[
				'meta_key'   => '_wp_page_template',
				'meta_value' => 'template-portfolio.php',
			]
		);
	
		foreach ( $pages as $page ) {
			$result[ $page->ID ] = $page->post_title;
		}
	
		return $result;
	}
}

if ( ! function_exists( 'jeg_portfolio_get_all_category' ) ) {
	function jeg_portfolio_get_all_category( $pageid ) {
		$category = [];

		$query = new WP_Query(
			[
				'post_type'  => 'portfolio',
				'meta_query' => [
					[
						'key'     => 'portfolio_parent',
						'value'   => [ $pageid ],
						'compare' => 'IN',
					],
				],
				'orderby'    => 'date',
				'order'      => 'DESC',
				'nopaging'   => true,
			]
		);

		$result = $query->posts;
		foreach ( $result as $key => $value ) {
			$termlist = get_the_terms( $value->ID, 'portfolio_category' );
			if ( ! empty( $termlist ) ) {
				foreach ( $termlist as $termkey => $termvalue ) {
					if ( isset( $termvalue->term_id ) && ! isset( $category[ $termvalue->term_id ] ) ) {
						$category[ $termvalue->term_id ] = $termvalue->name;
					}
				}
			}
		}

		return $category;
	}
}

if ( ! function_exists( 'jeg_portfolio_is_login_page' ) ) {
	/**
	 * @return bool
	 */
	function jeg_portfolio_is_login_page() {
		return in_array( $GLOBALS['pagenow'], [ 'wp-login.php', 'wp-register.php' ] );
	}
}

if ( ! function_exists( 'is_jeg_portfolio_page' ) ) {
	/**
	 * @return bool
	 */
	function is_jeg_portfolio_page() {
		global $post;

		$is_page       = false;
		$template_list = [
			'template-portfolio.php',
		];

		if ( is_page() ) {
			$template = get_post_meta( $post->ID, '_wp_page_template', true );
			if ( in_array( $template, $template_list ) ) {
				$is_page = true;
			}
		}

		if ( is_single() ) {
			if ( 'portfolio' === $post->post_type ) {
				$is_page = true;
			}
		}

		if ( is_search() ) {
			if ( isset( $_GET['post_type'] ) && 'portfolio' === $_GET['post_type'] ) {
				$is_page = true;
			}
		}

		return $is_page;
	}
}

if ( ! function_exists( 'portfolio_next_prev' ) ) {
	/**
	 * @param $parentid
	 * @param $currentid
	 * @param $to
	 * @param string    $category
	 *
	 * @return mixed
	 */
	function portfolio_next_prev( $parentid, $currentid, $to, $category = '' ) {
		$portfolioquery = [
			'post_type'  => 'portfolio',
			'meta_query' => [
				[
					'key'     => 'portfolio_parent',
					'value'   => [ $parentid ],
					'compare' => 'IN',
				],
			],
			'orderby'    => 'date',
			'order'      => 'DESC',
			'nopaging'   => true,
		];

		if ( $category !== '' ) {
			$portfolioquery['tax_query'] =
				[
					[
						'taxonomy' => 'portfolio_category',
						'terms'    => $category,
						'field'    => 'id',
						'operator' => 'IN',
					],
				];
		}

		$query = new WP_Query( $portfolioquery );

		$result      = $query->posts;
		$currentpost = 0;

		foreach ( $result as $key => $res ) {
			if ( $currentid === $res->ID ) {
				$currentpost = $key;
				break;
			}
		}

		if ( $to === 'next' ) {
			$nextpost = $currentpost + 1;
			if ( $nextpost >= sizeof( $result ) ) {
				$nextpost = 0;
			}

			$nextcontent = $result[ $nextpost ];

			return $nextcontent->ID;
		} else {
			$prevpost = $currentpost - 1;
			if ( $prevpost < 0 ) {
				$prevpost = sizeof( $result ) - 1;
			}
			$prevcontent = $result[ $prevpost ];

			return $prevcontent->ID;
		}
	}
}

if ( ! function_exists( 'jeg_portfolio_get_image_attachment_full' ) ) {
	/**
	 * @param $imageid
	 *
	 * @return mixed
	 */
	function jeg_portfolio_get_image_attachment_full( $imageid ) {
		$imagedata = wp_get_attachment_image_src( $imageid, 'full' );

		return isset( $imagedata[0] ) ? $imagedata[0] : '';
	}
}

if ( ! function_exists( 'jeg_portfolio_featured_heading' ) ) {
	/**
	 * @param $postid
	 *
	 * @return string
	 */
	function jeg_portfolio_featured_heading( $postid ) {
		$portfolioitem = jeg_metabox( 'jpt_media_builder_metabox.portfolio_media_builder', [], $postid );
		$featured      = '';

		if ( ! empty( $portfolioitem ) ) {
			foreach ( $portfolioitem as $idx => $portfolio ) {
				$portfoliotype    = $portfolio['media_type'];
				$loadclass        = ( $idx === 0 ) ? 'loaded' : 'notloaded';
				$mediacover       = JEG_PORTFOLIO_URL . '/assets/img/placeholder.png';;
				$mediacoverheight = 0;
				$mediacoverwidth  = 0;

				if ( isset( $portfolio['image_cover'] ) && ! empty( $portfolio['image_cover'] ) ) {
					$mediacover       = is_numeric( $portfolio['image_cover'] ) ? jeg_portfolio_get_image_attachment_full( $portfolio['image_cover'] ) : $portfolio['image_cover'];
					$mediacoversize   = wp_get_attachment_image_src( $portfolio['image_cover'], 'full' );
					$mediacoverheight = isset( $mediacoversize[2] ) ? $mediacoversize[2] : 0;
					$mediacoverwidth  = isset( $mediacoversize[1] ) ? $mediacoversize[1] : 0;
				}

				switch ( $portfoliotype ) {
					case 'image':
						$image       = JEG_PORTFOLIO_URL . '/assets/img/placeholder.png';;
						$imageheight = 0;
						$imagewidth  = 0;
						
						if ( isset( $portfolio['media_image'] ) && ! empty( $portfolio['media_image'] ) ) {
							$image      = is_numeric( $portfolio['media_image'] ) ? wp_get_attachment_image_src( $portfolio['media_image'], 'full' ) : $portfolio['media_image'];
							$imageheight = 0;
							$imagewidth  = 0;
						}

						$thumb = apply_filters( 'jeg_image_resizer', $image, 90, 90 );

						if ( $idx === 0 ) {
							$featured .=
								"<div class='portfolio-content-holder item' data-type='image' data-title='{$portfolio['media_title']}' data-thumb='{$thumb}'>
                                    <img src='{$image}' alt='{$portfolio['media_title']}' class='{$loadclass}' data-width='{$imagewidth}' data-height='{$imageheight}'/>
                                </div>";
						} else {
							$featured .=
								"<div class='portfolio-content-holder item' data-type='image' data-title='{$portfolio['media_title']}' data-thumb='{$thumb}'>
                                    <img src='#' data-src='{$image}' alt='{$portfolio['media_title']}' class='{$loadclass}' data-width='{$imagewidth}' data-height='{$imageheight}'/>
                                </div>";
						}

						break;
					case 'youtube':
					case 'vimeo':
						$thumb = apply_filters( 'jeg_image_resizer', $mediacover, 90, 90 );
						if ( $idx === 0 ) {
							$featured .=
								"<div class='portfolio-content-holder item' data-type='{$portfoliotype}' data-src='{$portfolio['media_url']}' data-title='{$portfolio['media_title']}' data-thumb='{$thumb}'>
                                    <div class='portfoliovideo-wrapper'>
                                        <img src='{$mediacover}' alt='{$portfolio['media_title']}' class='{$loadclass}' data-width='{$mediacoverwidth}' data-height='{$mediacoverheight}'/>
                                        <div class='videooverlay'></div>
                                    </div>
                                    <div class='portfoliovideo-container'><div class='video-container'></div></div>
                                </div>";
						} else {
							$featured .=
								"<div class='portfolio-content-holder item' data-type='{$portfoliotype}' data-src='{$portfolio['media_url']}' data-title='{$portfolio['media_title']}' data-thumb='{$thumb}'>
                                    <div class='portfoliovideo-wrapper'>
                                        <img src='#' alt='{$portfolio['media_title']}' data-src='{$mediacover}' class='{$loadclass}' data-width='{$mediacoverwidth}' data-height='{$mediacoverheight}'/>
                                        <div class='videooverlay'></div>
                                    </div>
                                    <div class='portfoliovideo-container'><div class='video-container'></div></div>
                                </div>";
						}
						break;
					case 'html5video':
						$thumb     = apply_filters( 'jeg_image_resizer', $mediacover, 90, 90 );
						$video_mp4 = $portfolio['video_mp4'];
						$video_webm = $portfolio['video_webm'];
						$video_ogg = $portfolio['video_ogg'];
						if ( $idx === 0 ) {
							$featured .=
								"<div class='portfolio-content-holder item' data-type='{$portfoliotype}' data-mp4='{$video_mp4}' data-webm='{$video_webm}' data-ogg='{$video_ogg}' data-title='{$portfolio['media_title']}' data-thumb='{$thumb}'>
                                    <div class='portfoliovideo-wrapper'>
                                        <img alt='{$portfolio['media_title']}' src='{$mediacover}' class='{$loadclass}' data-width='{$mediacoverwidth}' data-height='{$mediacoverheight}'/>
                                        <div class='videooverlay'></div>
                                    </div>
                                    <div class='portfoliovideo-container'><div class='html5-video-container'></div></div>
                                </div>";
						} else {
							$featured .=
								"<div class='portfolio-content-holder item' data-type='{$portfoliotype}' data-cover='{$mediacover}' data-mp4='{$video_mp4}' data-webm='{$video_webm}' data-ogg='{$video_ogg}' data-title='{$portfolio['media_title']}' data-thumb='{$thumb}'>
                                    <div class='portfoliovideo-wrapper'>
                                        <img alt='{$portfolio['media_title']}' src='#' data-src='{$mediacover}' class='{$loadclass}' data-width='{$mediacoverwidth}' data-height='{$mediacoverheight}'/>
                                        <div class='videooverlay'></div>
                                    </div>
                                    <div class='portfoliovideo-container'><div class='html5-video-container'></div></div>
                                </div>";
						}
						break;
					case 'soundcloud':
						$thumb     = apply_filters( 'jeg_image_resizer', $mediacover, 90, 90 );
						$featured .=
							"<div class='portfolio-content-holder item' data-type='soundcloud' data-src='{$portfolio['media_url']}' data-title='{$portfolio['media_title']}' data-thumb='{$thumb}'>
                                <div class='video-container'></div>
                            </div>";
						break;
					default:
						break;
				}
			}
		}

		return $featured;
	}
}

if ( ! function_exists( 'jeg_portfolio_remove_filters' ) ) {
	/**
	 * @param $tag
	 * @param $function_to_remove
	 * @param int                $priority
	 */
	function jeg_portfolio_remove_filters( $tag, $function_to_remove, $priority = 10 ) {
		if ( function_exists( 'jeg_remove_filters' ) ) {
			jeg_remove_filters( $tag, $function_to_remove, $priority );
		}
	}
}

if ( ! function_exists( 'jeg_portfolio_excerpt_masonry_length' ) ) {
	function jeg_portfolio_excerpt_masonry_length() {
		return 30;
	}
}

if ( ! function_exists('jeg_portfolio_get_query_paged')){
	function jeg_portfolio_get_query_paged() {
		$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1;
		$page  = ( get_query_var( 'page' ) ) ? get_query_var( 'page' ) : 1;
		return ( $paged > $page ) ? $paged : $page;
	}
}

if (!function_exists( 'jeg_portfolio_new_pagination')) {
	function jeg_portfolio_new_pagination( $pageid, $curpage, $totalPage = 0, $step = 2 ) {
		if ( $totalPage > 1 ) {
			$pagingCount = ( $step * 2 ) + 1;
	
			$html = '<div class="pagedot">';
	
			if ( $curpage > $step + 1 && $totalPage > $pagingCount ) {
				$html .= "<a data-page='1' href='" . esc_url( get_pagenum_link( 1 ) ) . "'><span>&laquo</span></a>";
			}
			if ( $curpage > 1 && $pagingCount < $totalPage ) {
				$html .= get_previous_posts_link( '<span>&lsaquo;</span>' );
			}
	
			/** loop page */
			for ( $i = jeg_portfolio_limitme( 'low', $curpage - $step, 1 ); $i <= jeg_portfolio_limitme( 'high', $totalPage, $curpage + $step ); $i++ ) {
				if ( $i == $curpage ) {
					$html .= '<span>' . $i . '</span>';
				} else {
					$html .= "<a data-page='{$i}' href='" . get_pagenum_link( $i ) . "'><span>{$i}</span></a>";
				}
			}
	
			if ( $curpage < $totalPage && $pagingCount < $totalPage ) {
				$html .= get_next_posts_link( '<span>&rsaquo;</span>' );
			}
	
			if ( $curpage < $totalPage - 1 && $curpage + $step + 1 <= $totalPage && $pagingCount < $totalPage ) {
				$html .= "<a data-page='{$totalPage}' href='" . get_pagenum_link( $totalPage ) . "'><span>&raquo;</span></a>";
			}
	
			$html .= '</div>';
	
			$html .= "<div class='pagetext'>
				<span class='pagenow'>" . esc_html__( 'Page', 'photology-themes' ) . "  <strong class='curpage'>{$curpage}</strong></span>
				<span class='pagetotal'>" . esc_html__( 'From', 'photology-themes' ) . "  <strong class='totalpage'>{$totalPage}</strong></span>
			</div>";
	
			return $html;
		} else {
			return;
		}
	}
}

if (!function_exists( 'jeg_portfolio_set_post_views')) {
	function jeg_portfolio_set_post_views( $postID ) {
		$count_key = 'post_views_count';
		$count     = get_post_meta( $postID, $count_key, true );
		if ( $count == '' ) {
			$count = 0;
			delete_post_meta( $postID, $count_key );
			add_post_meta( $postID, $count_key, '0' );
		} else {
			$count++;
			update_post_meta( $postID, $count_key, $count );
		}
	}
}

if (!function_exists('jeg_portfolio_blog_pagination')){
	function jeg_portfolio_blog_pagination( $query = null ) {
		global $wp_query;
	
		if ( ! $query ) {
			$query = $wp_query;
		}
	
		if ( $query->max_num_pages > 1 ) {
			?>
			<div class='blognormalpaging blogpagingholder'>
				<div class='blognormalpagingwrapper'>
					<?php echo jeg_portfolio_new_pagination( get_the_ID(), jeg_portfolio_get_query_paged(), $query->max_num_pages ); ?>
				</div>
			</div>
			<?php
		}
	}
}

if (!function_exists('jeg_portfolio_video_type')) {
	function jeg_portfolio_video_type( $url ) {
		if ( strpos( $url, 'youtube' ) > 0 ) {
			return 'youtube';
		} elseif ( strpos( $url, 'vimeo' ) > 0 ) {
			return 'vimeo';
		} elseif ( strpos( $url, 'soundcloud' ) > 0 ) {
			return 'soundcloud';
		} else {
			return 'unknown';
		}
	}
}

if (!function_exists('jeg_portfolio_audio_type')) {
	function jeg_portfolio_audio_type( $url ) {
		if ( strpos( $url, 'soundcloud' ) > 0 ) {
			return 'soundcloud';
		} else {
			return 'unknown';
		}
	}
}

if (!function_exists('jeg_portfolio_get_featured_header')) {
	function jeg_portfolio_get_featured_header( $w = null, $h = null ) {
		$featuredhtml = '';
		$imgid        = jeg_metabox( 'jpt_setting_metabox.image_cover', true, get_the_ID() );
	
		$featured_img = apply_filters( 'jeg_image_resizer', jeg_portfolio_get_image_attachment_full( $imgid ), $w, $h );
		$imgalt       = get_the_title( $imgid );

		if ( isset( $featured_img ) ) {
			$imgalt       = get_the_title( $imgid );
			$featuredhtml =
				"<div class='featured'>
					<a href='" . get_permalink() . "'>
						<img src='" . esc_url( $featured_img ) . "' alt='" . esc_attr( $imgalt ) . "'>
					</a>
				</div>";
		}
	
		return $featuredhtml;
	
	}
}

if (!function_exists('jeg_portfolio_get_category_link')) {
	function jeg_portfolio_get_category_link() {
		$catlink = [];
	
		foreach ( get_the_category() as $category ) {
			$catlink[] = '<a href="' . get_category_link( $category->term_id ) . '" title="' . $category->description . '">' . $category->name . '</a>';
		}
	
		return $catlink;
	}
}

/** next prev item */
if ( ! function_exists( 'jeg_next_prev_portfolio' ) ) {
	function jeg_next_prev_portfolio( $parentid, $currentid, $to, $category = '' ) {
		$portfolioquery = [
			'post_type'  => 'portfolio',
			'meta_query' => [
				[
					'key'     => 'portfolio_parent',
					'value'   => [ $parentid ],
					'compare' => 'IN',
				],
			],
			'orderby'    => 'date',
			'order'      => 'DESC',
			'nopaging'   => true,
		];

		if ( $category !== '' ) {
			$portfolioquery['tax_query'] =
				[
					[
						'taxonomy' => 'portfolio_category',
						'terms'    => $category,
						'field'    => 'id',
						'operator' => 'IN',
					],
				];
		}

		$query = new WP_Query( $portfolioquery );

		$result      = $query->posts;
		$currentpost = 0;
		$currentid   = intval( $currentid );

		foreach ( $result as $key => $res ) {
			if ( $currentid === $res->ID ) {
				$currentpost = $key;
				break;
			}
		}

		if ( $to === 'next' ) {
			$nextpost = $currentpost + 1;
			if ( $nextpost >= sizeof( $result ) ) {
				$nextpost = 0;
			}

			$nextcontent = $result[ $nextpost ];
			return $nextcontent->ID;
		} else {
			$prevpost = $currentpost - 1;
			if ( $prevpost < 0 ) {
				$prevpost = sizeof( $result ) - 1;
			}
			$prevcontent = $result[ $prevpost ];
			return $prevcontent->ID;
		}
	}
}

if (!function_exists('jeg_portfolio_limitme')) {
	function jeg_portfolio_limitme ( $type = 'high', $point, $limit ) {
		if ( $type == 'high' ) {
			return ($point > $limit) ? $limit : $point;
		} else {
			return ($point > $limit) ? $point : $limit;
		}
	}
}

if(!function_exists('jeg_portfolio_update_parent_id')) {
	function jeg_portfolio_update_parent_id( $post_id, $parent_id ) {
		$data = get_post_meta( $post_id, 'jpt_setting_metabox', true );

		if ( ! empty( $data ) && isset( $data['portfolio_parent'] ) ) {
			$data['portfolio_parent'] = $parent_id;
			update_post_meta( $post_id, 'jpt_setting_metabox', $data );
			update_post_meta( $post_id, 'portfolio_parent', $parent_id );
		}
	}
}

if(!function_exists('jeg_portfolio_update_thumbnail_id')) {
	function jeg_portfolio_update_thumbnail_id( $post_id, $new_id ) {
		$data = get_post_meta( $post_id, 'jpt_setting_metabox', true );

		if ( ! empty( $data ) && isset( $data['image_cover'] ) ) {
			$data['image_cover'] = $new_id;
			update_post_meta( $post_id, 'jpt_setting_metabox', $data );
		}
	}
}

if (!function_exists('jeg_portfolio_normal_excerpt_length')) {
	function jeg_portfolio_normal_excerpt_length() {
		return 50;
	}
}

if (!function_exists('jeg_portfolio_normal_excerpt_more')) {
	function jeg_portfolio_normal_excerpt_more() {
		return '...';
	}
}

if (!function_exists('jeg_portfolio_excerpt_masonry_length')) {
	function jeg_portfolio_excerpt_masonry_length() {
		return 30;
	}
}